From 1b22f9d172f8c6922f86b696b8f41d9782d6220a Mon Sep 17 00:00:00 2001
From: David Powell <djpowell@djpowell.net>
Date: Sat, 5 Jun 2010 16:50:30 +0100
Subject: [PATCH 5/6] changed default encoding to 'platform default encoding'.  This matches how we handle *out*.
 It is much more likely that command-line tools used by sh use platform default encoding.  Windows CRT barely supports UTF-8 for example.

---
 src/clj/clojure/java/shell.clj |   11 +++++++----
 1 files changed, 7 insertions(+), 4 deletions(-)

diff --git a/src/clj/clojure/java/shell.clj b/src/clj/clojure/java/shell.clj
index 2c2315a..1929e32 100644
--- a/src/clj/clojure/java/shell.clj
+++ b/src/clj/clojure/java/shell.clj
@@ -12,7 +12,8 @@
 collecting its stdout"}
   clojure.java.shell
   (:use [clojure.java.io :only (as-file copy)])
-  (:import (java.io OutputStreamWriter ByteArrayOutputStream StringWriter)))
+  (:import (java.io OutputStreamWriter ByteArrayOutputStream StringWriter)
+           (java.nio.charset Charset)))
 
 (def *sh-dir* nil)
 (def *sh-env* nil)
@@ -48,7 +49,8 @@ collecting its stdout"}
 
 (defn- parse-args
   [args]
-  (let [default-opts {:outenc "UTF-8" :inenc "UTF-8" :dir *sh-dir* :env *sh-env*}
+  (let [default-encoding (.name (Charset/defaultCharset))
+        default-opts {:outenc default-encoding :inenc default-encoding :dir *sh-dir* :env *sh-env*}
         [cmd opts] (split-with string? args)]
     [cmd (merge default-opts (apply hash-map opts))]))
 
@@ -82,13 +84,14 @@ collecting its stdout"}
   :inenc   option may be given followed by a String, used as a character
            encoding name (for example \"UTF-8\" or \"ISO-8859-1\") to
            convert the input specified by the :in option to the
-           sub-process's stdin.  Defaults to UTF-8.
+           sub-process's stdin.  Defaults to the platform default encoding.
   :outenc  option may be given followed by :bytes or a String. If a
            String is given, it will be used as a character encoding
            name (for example \"UTF-8\" or \"ISO-8859-1\") to convert
            the sub-process's stdout to a String which is returned.
            If :bytes is given, the sub-process's stdout will be stored
-           in a byte array and returned.  Defaults to UTF-8.
+           in a byte array and returned.  Defaults to the platform default
+           encoding.
   :env     override the process env with a map (or the underlying Java
            String[] if you are a masochist).
   :dir     override the process dir with a String or java.io.File.
-- 
1.6.5.1.1367.gcd48

